Package: thriftr
Type: Package
Title: Apache Thrift Client Server
Version: 1.1.8
Date: 2025-09-13
Authors@R: c(person("Marek", "Jagielski",
                    role = c("aut", "cre", "cph"),
                    email = "marek.jagielski@gmail.com"),
             person("Lixin", "Yu",
                    role = c("aut", "cph")))
Author: Marek Jagielski [aut, cre, cph],
  Lixin Yu [aut, cph]
Maintainer: Marek Jagielski <marek.jagielski@gmail.com>
Description: Pure R implementation of Apache Thrift.
    This library doesn't require any code generation.
    To learn more about Thrift go to <https://thrift.apache.org>.
License: MIT + file LICENSE
URL: https://github.com/systemincloud/thriftr
BugReports: https://github.com/systemincloud/thriftr/issues
Suggests: testthat
Encoding: UTF-8
Imports: R6, rly, stringi
RoxygenNote: 6.0.1
Collate: 'thrift.R' 'transport.R' 'rpc.R' 'parser.R'
        'protocol_binary.R' 'server.R' 'transport_buffered.R'
        'transport_memory.R' 'transport_socket.R' 'utils.R'
NeedsCompilation: no
Packaged: 2025-09-13 16:22:44 UTC; lupus
Repository: CRAN
Date/Publication: 2025-09-13 16:40:02 UTC
Built: R 4.6.0; ; 2026-04-25 22:49:19 UTC; unix
